define(
//begin v1.x content
({
	widgetLabel: "Batchrechtschreibprüfung",
	unfound: "Nicht gefunden",
	skip: "Überspringen",
	skipAll: "Alle überspringen",
	toDic: "Zum Wörterbuch hinzufügen",
	suggestions: "Vorschläge",
	replace: "Ersetzen",
	replaceWith: "Ersetzen durch",
	replaceAll: "Global ersetzen",
	cancel: "Abbrechen",
	msg: "Keine Rechtschreibfehler gefunden",
	iSkip: "Diesen Fund überspringen",
	iSkipAll: "Alle entsprechenden Funde überspringen",
	iMsg: "Keine Rechtschreibvorschläge"
})

//end v1.x content
);
